@@ -232,7 +232,7 @@ class ToOneLevel:
       iteration = value.items()
 
     for i, v in iteration:
-      i = self._validate_replace_underscore(i)
+      i = self._validate_replace_underscore(str(i))
 
       if self._validate_is_array_dict(v):
         self._scan_down(f'{key}.{i}', v)
